==> ideaIC-173.4301.1-sources.jar: org/jetbrains/plugins/groovy/lang/resolve/processors/GrDelegatingScopeProcessorWithHints.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.plugins.groovy.lang.resolve.processors;

import com.intellij.openapi.util.Key;
import com.intellij.psi.PsiElement;
import com.intellij.psi.ResolveState;
import com.intellij.psi.scope.PsiScopeProcessor;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.EnumSet;

public class GrDelegatingScopeProcessorWithHints extends GrScopeProcessorWithHints {
  private final PsiScopeProcessor myDelegate;

  public GrDelegatingScopeProcessorWithHints(@NotNull PsiScopeProcessor delegate,
                                             @Nullable String name,
                                             @Nullable EnumSet<DeclarationKind> resolveTargets) {
    super(name, resolveTargets);
    myDelegate = delegate;
  }

  @Override
  public boolean execute(@NotNull PsiElement element, @NotNull ResolveState state) {
    return myDelegate.execute(element, state);
  }

  @Override
  public void handleEvent(@NotNull Event event, @Nullable Object associated) {
    myDelegate.handleEvent(event, associated);
  }

  @Override
  public <T> T getHint(@NotNull Key<T> hintKey) {
    T hint = super.getHint(hintKey);
    if (hint != null) return hint;

    return myDelegate.getHint(hintKey);
  }
}

==> ideaIC-213.7172.25-sources.jar: org/jetbrains/plugins/groovy/lang/resolve/processors/GrDelegatingScopeProcessorWithHints.java <==
// Copyright 2000-2017 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package org.jetbrains.plugins.groovy.lang.resolve.processors;

import com.intellij.openapi.util.Key;
import com.intellij.psi.PsiElement;
import com.intellij.psi.ResolveState;
import com.intellij.psi.scope.PsiScopeProcessor;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.EnumSet;
import java.util.Set;

public class GrDelegatingScopeProcessorWithHints extends GrScopeProcessorWithHints {
  private final PsiScopeProcessor myDelegate;

  public GrDelegatingScopeProcessorWithHints(@NotNull PsiScopeProcessor delegate,
                                             @NotNull DeclarationKind target,
                                             DeclarationKind @NotNull ... targets) {
    this(delegate, EnumSet.of(target, targets));
  }

  public GrDelegatingScopeProcessorWithHints(@NotNull PsiScopeProcessor delegate, @Nullable Set<DeclarationKind> resolveTargets) {
    this(delegate, null, resolveTargets);
  }

  public GrDelegatingScopeProcessorWithHints(@NotNull PsiScopeProcessor delegate,
                                             @Nullable String name,
                                             @Nullable Set<DeclarationKind> resolveTargets) {
    super(name, resolveTargets);
    myDelegate = delegate;
  }

  @Override
  public boolean execute(@NotNull PsiElement element, @NotNull ResolveState state) {
    return myDelegate.execute(element, state);
  }

  @Override
  public void handleEvent(@NotNull Event event, @Nullable Object associated) {
    myDelegate.handleEvent(event, associated);
  }

  @Override
  public <T> T getHint(@NotNull Key<T> hintKey) {
    T hint = super.getHint(hintKey);
    if (hint != null) return hint;

    return myDelegate.getHint(hintKey);
  }
}
